#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dec
version:              0.0.6
visibility:           public
id:                   dec-0.0.6-6ruRTurpeWhLuaL9pSxJAK
key:                  dec-0.0.6-6ruRTurpeWhLuaL9pSxJAK
license:              BSD-3-Clause
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/dec
synopsis:             Decidable propositions.
description:
    This package provides a @Dec@ type.

    @
    type Neg a = a -> Void

    data Dec a
    \    = Yes a
    \    | No (Neg a)
    @

category:             Data, Dependent Types
abi:                  ea6823b0c8a71ac5bc4caa9ff428eef5
exposed:              True
exposed-modules:      Data.Type.Dec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dec-0.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dec-0.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dec-0.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dec
hs-libraries:         HSdec-0.0.6-6ruRTurpeWhLuaL9pSxJAK
depends:              base-4.18.2.1 boring-0.2.2-95zAwRwmONjM683l7QC17
haddock-interfaces:   /usr/share/doc/haskell-dec/html/dec.haddock
haddock-html:         /usr/share/doc/haskell-dec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

